package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Mar 27, 2023
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
CurrentTikv string `yaml:"currentTikv"`
Tikvs []TikvConfig `yaml:"tikvs"`
}
type Security struct {
ClusterVerifyCN []string `yaml:"cluster-verify-cn"`
}
type TikvConfig struct {
Name string `yaml:"name,omitempty"`
Address []string `yaml:"address,omitempty"`
Security Security `yaml:"security,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.